@@ -19,10 +19,13 @@ This submodule gives basic utilities for printing to the terminal.
 '''
 
 import textwrap, subprocess, os, sys
+from .env import sys_encoding
+from ..compat import is_py2
+from ..exceptions import DXCLIError
 
 if sys.stdout.isatty():
     try:
-        tty_rows, tty_cols = map(int, subprocess.check_output(['stty', 'size'], stderr=os.devnull).split())
+        tty_rows, tty_cols = map(int, subprocess.check_output(['stty', 'size'], stderr=open(os.devnull, 'w')).split())
         std_width = min(tty_cols - 2, 100)
     except:
         tty_rows, tty_cols = 24, 80
@@ -114,3 +117,31 @@ def fill(string, width_adjustment=0, **kwargs):
     if "break_on_hyphens" not in kwargs:
         kwargs["break_on_hyphens"] = False
     return textwrap.fill(string, **kwargs)
+
+def pager(content, pager=None, file=None):
+    if file is None:
+        file = sys.stdout
+
+    pager_process = None
+    try:
+        if file != sys.stdout or not file.isatty():
+            raise DXCLIError() # Just print the content, don't use a pager
+        content_lines = content.splitlines()
+        content_rows = len(content_lines)
+        content_cols = max(len(i) for i in content_lines)
+
+        if tty_rows > content_rows and tty_cols > content_cols:
+            raise DXCLIError() # Just print the content, don't use a pager
+
+        pager_process = subprocess.Popen(pager or os.environ.get('PAGER', 'less -RS'),
+                                         shell=True, stdin=subprocess.PIPE, stdout=file)
+        pager_process.stdin.write(content.encode(sys_encoding))
+        pager_process.stdin.close()
+        pager_process.wait()
+    except:
+        file.write(content.encode(sys_encoding) if is_py2 else content)
+    finally:
+        try:
+            pager_process.terminate()
+        except:
+            pass
